@@ -1,4 +1,4 @@
 #!/usr/bin/python
 # -*- coding: UTF-8 -*-
 
-from quant1x.formula.base import *
+from quant1x.base.formula import *
\ No newline at end of file
